import {
  Enums,
  RenderingEngine,
  setVolumesForViewports,
  volumeLoader,
} from "@cornerstonejs/core";
import { createImageIdsAndCacheMetaData } from "../CornerstoneDicomLoader/createImageIdsAndCacheMetaData";
import { initCornerstone } from "../CornerstoneDicomLoader/init";
import { useEffect, useRef } from "react";
import * as cornerstoneTools from "@cornerstonejs/tools";
import { PublicViewportInput } from "@cornerstonejs/core/dist/types/types";
import { setCtTransferFunctionForVolumeActor } from "./setCtTransferFunctionForVolumeActor";
interface CorsshairProps {
  children?: JSX.Element;
}

const {
  ToolGroupManager,
  Enums: csToolsEnums,
  CrosshairsTool,
  StackScrollMouseWheelTool,
} = cornerstoneTools;

const toolGroupId = "MY_TOOLGROUP_ID";
const volumeName = "CT_VOLUME_ID"; // Id of the volume less loader prefix
const volumeLoaderScheme = "cornerstoneStreamingImageVolume"; // Loader id which defines which volume loader to use
const volumeId = `${volumeLoaderScheme}:${volumeName}`; // VolumeId with loader id + volume id

const renderingEngineId = "myRenderingEngine";
const viewportA = "CT_AXIAL";
const viewportB = "CT_SAGITTAL";
const viewportC = "CT_CORONAL";

const viewportColors = {
  [viewportA]: "rgb(200, 0, 0)",
  [viewportB]: "rgb(200, 200, 0)",
  [viewportC]: "rgb(0, 200, 0)",
};

const { ViewportType } = Enums;

const StudyInstanceUID =
  "1.2.840.113564.345049290535.9692.637552042156233117.433089";
const SeriesInstanceUID =
  "1.3.12.2.1107.5.1.4.76315.30000021042706150001900118311";

export const Corsshair = (props: CorsshairProps) => {
  const viewportA = useRef(null);
  const viewportB = useRef(null);
  const viewportC = useRef(null);

  const run = async () => {
    await initCornerstone();
    // Get Cornerstone imageIds and fetch metadata into RAM
    const imageIds = await createImageIdsAndCacheMetaData({
      StudyInstanceUID,
      SeriesInstanceUID,
      wadoRsRoot: "/dicom-web",
    });

    const volume = await volumeLoader.createAndCacheVolume(volumeId, {
      imageIds,
    });

    console.log(volume)

    // Instantiate a rendering engine
    // const renderingEngine = new RenderingEngine(renderingEngineId);

    // if (viewportA.current && viewportB.current && viewportC.current) {
    //   // Create the viewports
    //   const viewportInputArray: PublicViewportInput[] = [
    //     {
    //       viewportId: viewportA.current,
    //       type: ViewportType.ORTHOGRAPHIC,
    //       element: viewportA.current,
    //       defaultOptions: {
    //         orientation: Enums.OrientationAxis.AXIAL,
    //         background: [0, 0, 0],
    //       },
    //     },
    //     {
    //       viewportId: viewportB.current,
    //       type: ViewportType.ORTHOGRAPHIC,
    //       element: viewportB.current,
    //       defaultOptions: {
    //         orientation: Enums.OrientationAxis.SAGITTAL,
    //         background: [0, 0, 0],
    //       },
    //     },
    //     {
    //       viewportId: viewportC.current,
    //       type: ViewportType.ORTHOGRAPHIC,
    //       element: viewportC.current,
    //       defaultOptions: {
    //         orientation: Enums.OrientationAxis.CORONAL,
    //         background: [0, 0, 0],
    //       },
    //     },
    //   ];

    //   renderingEngine.setViewports(viewportInputArray);

    //   volume.load();

    //   await setVolumesForViewports(
    //     renderingEngine,
    //     [
    //       {
    //         volumeId,
    //         callback: () => setCtTransferFunctionForVolumeActor,
    //       },
    //     ],
    //     [viewportA.current!, viewportB.current!, viewportC.current!]
    //   );

    //   // Render the image
    //   renderingEngine.renderViewports([
    //     viewportA.current!,
    //     viewportB.current!,
    //     viewportC.current!,
    //   ]);
    // }


  };

  useEffect(() => {
    run();
  }, []);

  return (
    <div
      style={{
        display: "flex",
        justifyContent: "space-evenly",
        gap: 20,
        height: 300,
      }}
    >
      <div ref={viewportA}></div>
      <div ref={viewportB}></div>
      <div ref={viewportC}></div>
    </div>
  );
};
